package com.redhat.thermostat.tools.eclipse.plugin.editor;

import org.eclipse.jface.window.Window;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.forms.DetailsPart;
import org.eclipse.ui.forms.editor.FormPage;

import com.redhat.thermostat.tools.eclipse.plugin.Messages;
import com.redhat.thermostat.tools.eclipse.plugin.model.Command;
import com.redhat.thermostat.tools.eclipse.plugin.model.Plugin;

/**
 * The master of the "Commands" page. Shows a list of all commands.
 */
public class CommandsMasterDetailsBlock extends BaseMasterDetailsBlock {

    private CommandEditPage editPage;

    public CommandsMasterDetailsBlock(FormPage formPage) {
        editPage = new CommandEditPage(formPage);
    }

    public void setModel(Plugin model) {
        super.setModel(model);

        editPage.setModel(model);
    }

    @Override
    protected void registerPages(DetailsPart detailsPart) {
        detailsPart.registerPage(String.class, editPage);
    }

    @Override
    String getSectionTitle() {
        return Messages.CommandsMasterDetailsBlock_title;
    }

    @Override
    String getSectionDescription() {
        return Messages.CommandsMasterDetailsBlock_description;
    }

    @Override
    Object[] getListViewModel() {
        return model.getCommandNames().toArray();
    }

    @Override
    void addButtonSelected(Shell shell) {
        NewNameDialog dialog = new NewNameDialog(shell);
        dialog.create();
        if (dialog.open() == Window.OK) {
            Command command = new Command();
            command.setName(dialog.getName());
            model.addCommand(command);
            sectionPart.markDirty();
        }
    }

    @Override
    void removeButtonSelected(Object selectedItem) {
        model.removeCommand((String) selectedItem);
        sectionPart.markDirty();
    };
}
